
# q-expansion of newform 63.12.a.f, downloaded from the LMFDB on 17 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 63
weight = 12
poly_data = [-6609, -815, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0], 1], [[-1, 2, 0], 1], [[-539, -14, 1], 1]]

hecke_ring_character_values = None
aps_data = [[23, 1, 0], [0, 0, 0], [-1147, -115, -37], [-16807, 0, 0], [-451527, -6325, -275], [-304820, -22302, 6222], [821159, 12927, -3047], [3649436, -108936, 9896], [-3253481, -84471, -134497], [-65560718, -291256, 403608], [-24412280, -2272392, 604904], [-290114208, 4357854, 1000050], [122817541, -17737175, 1163071], [189419028, 23878512, 1194512], [-6617838, 275742, -1967406], [-1565381132, 50182206, -1330222], [-6604975750, 20834634, 6012934], [-2153752426, 19105128, -5480008], [8472470438, 102656358, 19352906], [-13920732727, 150800775, -2636975], [-5973803224, 112832802, -51375122], [-11363226978, -136686222, 102845342], [-8725645780, -439197696, 40014400], [-33881762011, -127517047, -146341729], [1322689844, 266287086, 203886466], [33903525947, 1512174919, 214205937], [92836109332, 605151396, 25569244], [-11911883383, 556114475, 277110797], [34069047846, -2558280672, -653690400], [-208986227734, 2241806756, -232034116], [295505282990, 4291649154, 622477006], [141662417088, -15625182916, -377553116], [-103787156984, -12872690514, 2196708866], [-209400194564, 1583430480, -883107088], [358349461332, 13429440606, -1465836750], [-129654512616, -3413269872, -1189555408], [160582684842, -46884348, 2440365628], [-217931814966, 4248459954, -7276120994], [1246014730410, 11513824670, -1721153582], [1551963141967, 27917628811, 612184141], [-1957411531265, -2315774675, -4086095525], [-1512293109448, 70892393166, 1386027266], [-985387192763, -59189851837, -12629304459], [-4711023360568, -43634663766, 4987440582], [-817116854988, 46298997806, -5728597022], [-1025881607172, 37899097020, -57075804], [-2175255507680, -99624492756, -17937506700], [-3207674288516, -45242242092, -15605872500], [3029249897058, 191292033162, -30881265594], [200310828504, -271993574178, -1832659150], [-9206517348432, -129917634906, 3700110666], [-6912901855321, -267011535087, 24483992791], [1183300887924, 122552758494, 40655407058], [-5338144498326, 30651014378, 67623946150], [6942277319013, 50908302673, -23263291753], [-2593811119025, -82429408879, -77119184553], [-3462309245603, 192158832813, 9039376187], [3652672036420, -566760886596, -77738386620], [-12921534799412, 194828781330, 4623571038], [22405399066748, -415748334038, 37775192742], [-17697083792124, -240783521112, -187609366856], [-6597619169581, -659740740977, -71929871703], [35768390140032, -438678535788, -143362504532], [-23185611989862, 497859980622, -147229096158], [-5151969818630, -453116933856, -93313952672], [-32172836405484, 773371075302, 112831716522], [21270763517176, 1389429031788, -175026702284], [-43924488861714, 1124865272484, -220557361412], [47784919743359, 301124515909, 228214357635], [24725021124646, 597955273416, -355032551592], [-35350548171281, 528452628695, 440885289729], [-110652466350791, 303723985831, -184227901391], [-26162766319448, 190716725592, 218317939688], [54484733636238, 319544582400, -545915324800], [64236722228672, 1360648136628, 527125096492], [-95943008166620, -1194961468596, -58698683500], [12428489418162, 2590769535312, -490609291824], [-109507135914158, 2705287195980, -562017443404], [93965399068196, -980837641062, -205830668426], [4337473629860, -1057940076762, 246508509258], [29292250851834, 710296298850, 575142062958], [163585094886268, -3973784019822, 153058275550], [165140352404829, 2116843388619, 1227683824941], [-171958914198522, 3384556788636, 416616155716], [-88234437733144, -3867679133136, -1011877969904], [138171036623863, -1549172943267, -543342297685], [48111672214998, 193137867912, 1560738272568], [-359223478442502, -3622875921504, 612257986144], [-115069869598581, -8101206246353, -1534135060471], [525727081114634, -4530268220346, -54360219094], [34304220772558, -6795115761138, -348461443294], [-282710256708914, 14778711319666, 191931348958], [-102984962797300, 551702757996, -124407928012], [-3283224624377, 5863495868125, -2111666832725], [197984581679272, -9658898093340, 2347619768124], [585975626558064, 9053549889096, 3707380678200], [-436562429417747, 14881399313869, 335267743195], [91491055195667, 21735525615819, 2173550680237], [7810184477028, 12746377999800, 565655125000], [-178557705037012, 93000981546, -1525627490682], [-464528525134050, 22708478882142, -2797658421806], [853541035555408, -17038738512166, 843936475158], [827402124589182, 4960309988366, -2477011662494], [-160659933030032, 32017601014838, 2709672478074], [1278975862677234, -23724640918926, 313993690718], [-1242851000009162, 44213654170188, 1845017301396], [1701824519497510, -2936400630274, 2408748132594], [-2083676233843033, 4694847690063, -163596853367], [-271983333968507, -3013599684357, 5308795354109], [1768306419733438, 9921083690412, 6545674239284], [1025488365021544, -34362384549624, 358971485176], [987824406353830, 29335380639912, 5794250240856], [901717424525420, -49556350832694, 1105056608134], [-1657326781362792, 6503113440036, -8670852645188], [-1476161205925130, -12554661335310, -1389747840674], [149548697192032, 1878749875182, -15192403984510], [-769961280352716, -43395206873472, -114677813920], [2927472103551110, 10122215490370, 3239488496718], [-1083157493955650, 77594405415564, -3608402674060], [1663123258498637, 22188542922975, -902750713991], [1232482135170946, 17424994481028, 70841471676], [-54778432065164, 3003183067230, -6457009250574], [-718709402609153, 19148922427539, 3206031263621], [-1925747925175421, 61595937962817, 4993865452391], [-1280895765109016, 11276110322892, 9912986811796], [-5320305433173686, 9052093921968, 4034993035760], [-1368993066209610, -82202667831432, 18734883165768], [2393104272310672, 48586186253328, 7846600478192], [-538589524722820, 62864663332428, 3547979928180], [5640158613821676, 10384504678530, -13960209644754], [2495730698267330, 27313159149018, 1038987340918], [-604407941097639, 12999454266087, -19960971313935], [3629094858925368, 79506588721176, 13158526238248], [-4886690807467530, -56999421307800, -3766674594088], [1332455247876557, -84046535276079, 24304345538839], [-5424260057565618, -76002849650844, 7663693312700], [-3150472502359089, -136505767222445, 25203358225733], [-340412353358704, 34527125530116, -4775491243300], [6434143956295855, 42958920476507, -3062213181315], [-6461522914944282, -59737031753856, -31606120996800], [2047553427397184, 265282267508028, 1653086774052], [513850422976168, -185792897769782, -48089289829082], [1107678327020130, 108086773982886, 43377476222730], [-7970242774516399, -39602167617357, 24726662562373], [1775790770192784, -107863023882978, 10873591372850], [-3069168397630986, -134033993171662, 42293698548766], [2792102524035182, 242351349278184, -47797599461448], [5304230693057029, 123067510018457, 815708203023], [3745070406848464, -450192528883764, -23351975859596], [11491705901764827, -171253020528003, -23224753300533], [-1145622864285506, -12135116443320, 46380871176120], [-8511745254795229, -195330694593741, -16553637851195], [-12921927805992024, -2830907487708, -5324672318212], [-13867951210797926, 64254549935134, 52581599033170], [15135589276165444, 125729286537744, 35089963710064], [-10836658013917579, 160891264333875, 52488418977541], [17338354156537708, -52495479932724, -18293127028268], [-4770253885901439, 75901728531973, -75014100419005], [-1739910111227058, -127656308918772, -32506592565996], [22295885621052877, 136379309935885, 17797309202203], [-2537804615210151, 342649095804499, 15159845715365], [-974199649471042, -133394187097928, -69674008308216], [8527370569430326, 459917576638866, -6805540677570], [-938826025011428, -543536338479768, -47884549657960], [2917767017533900, 199703845751730, 77755967289758], [27541927899927732, -100083651945900, 36904636015500], [6752353699532756, -145466195590980, 66095443029348], [-9097123526899662, -61159491711612, 55447421988796], [-5721840534556732, 406067448160926, 39284871618482], [-9197564943214269, -66722160483617, 46955395721561], [23794735457794669, 144393873041463, -85465331219359], [2469248680927610, 621689945452308, -29913425871956], [25446172251048901, -743812026670581, -88276896013075], [-2593202436821892, 300324161664558, -195179839466782], [-48806915095499388, -63806596233588, -18875173493164], [25572809436003215, 581721462092431, 61073563970121], [46104883998476062, -206937216101322, 65277895078458], [33352428998103178, -30228624820744, -78281414649624], [14700159404890832, 335852150139864, -108539611806968], [-37636922713679486, -326626254453204, -16241930259756], [-11451093137683462, -582265394548074, -205277205218406], [50124276556301088, -357804105906612, -91991655734892], [-9411159776578364, 82266050191482, 49653853396918], [-22713579670652293, -886236092131853, 221520656005509], [29357953564122483, -299607312745563, 205435644313059], [-3091270610881617, 501520855333843, 196634323257989], [-1268478308599518, -342715084516188, 205096973675068], [47156409933628836, -424943733892608, 87008248098688], [-59734259404917996, -686714384602026, -135982135131398], [-23336451146725420, -431672644393540, 187059475325924], [-90759459275577932, -315926128964610, 112870604940210], [-37584937758044759, -19888899268149, 151320520107629], [8230807060531964, -818297463904272, -19353342514608], [-55339596603668653, -1415229344625033, -5840707958015], [-27035678049154755, -568784576585233, 24779815183465], [-69589199903496841, 797848853456823, -168054690739103], [-72335671801812548, 621852605403750, -135970084155350], [28125198263179140, 1385618889219426, -120900875894130], [-115389319750530095, -885732539503419, 128228563081859], [45145520665372774, -483160123553070, -117594627552706], [12421177241704052, -1026785637561194, -95816890268550], [-54206822183910292, -752589379947708, 86148967650204], [-70308677462349956, -1527675945488838, -417334640011018], [45005627091249412, 931848027295086, -180186498324990], [56831184769702720, 1740625681908388, -38276901532292], [-106869301521680153, 1406093608357171, 74605346474533], [68496019719672884, 1018065092398092, 575745070659220], [-68952975422970687, -1811315438219493, 352397782773789], [-5054926712135826, 1397601494232312, -63125711076600], [84431704536378984, 1070966795710500, -526638452230436], [9813565548894410, -1509318198855288, -9791823152456], [-29486491549680223, -975663864142239, -275241915847961], [-86656496782880924, 710884336646340, -145753242827364], [-77772523525983340, 2835621261878528, -14905178808064], [-34334514248830142, 2010896952848662, 80691370918618], [-45949515879321506, -80817627589236, -86930177401452], [-90197782018590324, -4134086594604, -55784072182900], [-29765078471516717, -1055786031049165, -492215356890555], [98032228345499263, 507484282085873, -60442701325833], [22676141787243162, -4735363683717984, -243725665430784], [4460653482262030, -2804628191288256, -387251682785600], [-5467359724793260, 210047349617892, -619436234633188], [-193043727202909182, -137157993411332, -195113275865116], [-10856895475311024, 1695096470594016, 538790317630112], [-27473799490985096, 248644144066516, 959806075571212], [-38060800856783632, 468831025544670, -559304397128334], [-16583272243069179, 3561489692904809, -528918770275073], [58897903029511471, 80298530045401, 738043780911823], [-31105076659869028, 1970304575673420, 313892669218356], [134615138755404379, 2331660037210233, -307950980092945], [207772317351587334, 160787629332000, 919815704060512], [-38604225252786864, -3492091253630700, -532315730154068], [17641210327994340, 5580731606740236, -952792673682028], [71448844467679150, -3470533399564744, -70255728871800], [-140164116453930312, -4401326355646428, -249373148144868], [36963442062428056, 6449401974944952, -421389941149048], [-100221056882264884, -3788447360650362, 1041149932965290], [-85684718891551704, -2272513814324822, 590128083922886], [-313928506489776765, -2591360945035119, -174990492559209], [156731297796267464, -348127877095616, 390536952331776], [-74791599127521965, 3259767366074409, 1374990908934335], [-60077892987819216, -1173014098141572, 158927928820452], [-45419166138579100, -7815131696485116, -1165584481544612], [-49769019080186524, 2821220793028386, -313088478444082], [19327041639275417, 1740484477974093, 1375419228551803], [-61768541356961454, 241245732603494, 1406491888880266], [-503277969685623912, 678717404766072, -656379045241880], [-3858869944214510, -6459607930795238, -1294005867849674], [326669367727944730, 3151677305916378, -995405312282442], [-92897853000277965, 3755350171931637, -950787632098797], [319609081432967090, 4244527176700212, -978359067151956], [125323931660316055, 98180513805903, -635714220714103], [20427984141895717, -387850778089429, -688600838320947], [191122898977272544, -5902807957359318, 109255511364390], [455428993652560135, 487723688791331, -144545863077003], [-454793771098508515, -3247082817686561, -356426793826311], [77473522507725612, -7052156445141918, -1358123000888818], [325816868142679768, -11432964437729820, -997519421534692], [114885395566122391, -9360571713412533, -919034445907123], [-76727224298364250, 14765179515493140, 1162466382807372], [667871662456508030, 4578720434909298, 38537256759582], [-219575420769323557, 11161678576128433, -652355009103753], [3103401960890816, -7329047759531514, -1885243538696502], [-162743360030205346, 3566177127718272, 440758105029984], [391454957649843763, -2897225299108157, 659896325162677], [642470151072952352, 4582874473211988, 1333766953762572], [10874183697436696, 3868318300826994, -2310790042020034], [-16827284133443301, -13616737653264925, -180637854872363], [-66658985600142010, 3688319256887502, -729758359623454], [484556646609828258, 7308333962516480, -1880054350132448], [35976690070199550, -9402608966804352, -1384651737678176], [473536523091859388, 8400792657850560, 2300389609285248], [176159697797234488, 13943290213052514, 1836946600978734], [-468761067518113196, -10832890664754612, -833496083759084], [-1117720084584368448, -1644928755204798, 321499800942478], [-204634974928815372, 5067455317058052, 1211373462266492], [93824884312539309, -4516404036507193, 1564664696148433], [-368688624497456436, 9626331721000554, -776872929561018], [641404907203352760, 4543914647680146, 50859382031902], [-785786658913709902, 1759127110914442, -1478197911417018], [141375196819261332, 14787894529022668, -2676044950362412], [-24378741864438442, 5447850142344066, 2904301977508558], [-219615235394678748, 25785349780800580, 958205058310172], [721517988046842554, -11186555288550372, -1343152710497308], [-445918990131829740, -11144413898833176, -52146045028264], [855458318387069837, 9591830263378587, 660641490456925], [-174331733241840974, -1505435356774656, -4350550388238720], [-425135013713579896, 4382303878931562, -866458769791802], [-165140293018506212, 16341270666196716, 1731757404096532], [-643099195024840867, 34675281001066521, 1133145704127247], [181563023738280060, -22381530364205650, -1800288021004766], [-197381648083129744, 2974650818163164, 1895199670648964], [612746220148086588, 23431389486263370, -2431517554913658], [-676936131848251426, -4794838818128874, -1406442443632742], [13765977703766350, 4604603211853992, 2581940247236376], [767392734551095695, 2906945756513147, 3944229017359837], [332401435858523292, -18373917008389356, -2494419820763636], [233536975163590385, -16064146413386015, 3420220726695591], [-1086245797381342206, -15521183662408814, 4924841082121214], [272853745097696900, 21585830117234832, -888412884752976], [-865607601038701342, 23591281633831656, -830713015814504], [-631257635500650206, -21176717801031384, 2213412304416632], [175241480581757634, 5284009453179438, 4503522793182466], [626744903680838381, -6062852209824385, -541418436723367], [-432001630002220318, -12749513049777150, 2618973530831950], [166873119398742390, -28701845387340372, -6313463485760460], [-384468329375181981, -2103545478771375, -3389112431392809], [341823824319614760, 26293618787917302, 1337829918247002], [2505989099685201, 6155015644337951, -1929810182561927], [31092886752863428, -8974259887109814, 6731601169801446], [-988745990809238484, 13022636703139524, 3791353081078812], [-42605537319285306, -16944708250132532, -4132723693318924], [-1399966232566345060, -14164319539787214, -463219636944290], [-76511523193724704, -20092153300497108, -3376626837281612], [-1524688131716794697, 50675955695055721, 2219306975251135], [237492657506837480, 17270816776423938, 7261439407414158], [-460339529102149952, -5633113299479364, 10050469270421732], [-387933221261875601, -26877198726533655, 5631663937449407], [-1799492485820955712, -27636697582771086, -1500724935373666], [-760195664603075544, 32621633603737782, 770768391684474], [-1019409419115550684, -43690434935137056, 662907883031232], [312597771566852716, 7774668745835022, 5354519249919426], [88912026225216035, -6095881875545289, 4103344707019585], [-677450553786980340, -43892377890956316, -4832328031675012], [1890966652972566050, 10894554504091044, -5668090438473860], [835977191227049464, 27846929367704826, -2698003439957610], [-1506692447085611586, 8561928793382046, 640986024325714], [-1236467519930043436, -398396481948072, 1403271706958280], [182110498701249729, -19905999537862313, 2446367503649153], [-86214703147698814, 11218086631515744, -13807330022150528], [827976908008419834, -21068102757822372, -1823416511268668], [2326889989731534318, 20485877651064204, 11699990113378548], [549505255971283484, 23992223794791876, -1425884743256196], [-1307394173065769350, 26834170661572482, 6545893779600718], [118544880405454846, -59073179847775578, -4590178494641910], [-756972254912900166, 10703272387304234, 9690525917805670], [2622566163914884126, -35801571512583720, -572094569330648], [1522185514312479557, -4922068109790543, 10147897566696247], [483672024082191852, 7111209129673662, 2256630134597042], [-408264229895173596, -22886718286566420, 10538620600409620], [360323087311358350, 51149354132042784, 12331585423646688], [-788427337907633956, -44677686986212694, 13240471341222], [-173590822770434879, -18786160755813087, -7389867188461465], [2647934501862580500, -24324220380942252, 65717336139724], [315143298434785274, 63179388162043936, 1136789942673600], [1370296666690565637, -47660798216032201, -4320288308853407], [3233018407668244500, -50492208607111134, 1036549257051982], [-557964100910403364, 22931364857945832, -9649487377981864], [-1614860275050630364, 36162742629057996, 7993390987254292], [1537117918510476707, 40959245586187471, 10071451473943593], [477794843902858440, 59528902618910700, 9183007073479636], [-247155724937057604, -9193920303146130, -11758528285600926], [2178232709719497212, -53195667772579666, -4672980612476638], [-1858160809428800220, 40445755799334732, 7336327863908436], [3005755587799084094, 14792378423097168, 15055411884002096], [-1146376195417974593, -43935595245207521, 432767584329529], [-2662826612875574816, -24573686307460080, 4120850131340528], [11042054968137172, -44578897858845648, 14508275723632400], [-2116687493979287566, 1760756408699836, 8405065841547492], [2910378264994304381, -35294692815754029, -1926400034476571], [489739786804531078, -11590048974717000, 1164519697553288], [-140913244708447015, -24160609513184731, 1406754715878563], [-432762640760501147, 2750486264287587, -2417235030030379], [3995466920516248093, 10019836035641575, 10136715092587441], [3727941740087591112, 38791007233046460, 5594465963383076], [4879881211278605124, -34785231049311354, 6970936566793738], [-5092222265450339007, 2827284494235145, -4808059230285121], [1053126310896396062, -94115461506800310, -1413069748127482], [835042001730585240, -1629121353805278, -13631366284188402], [-4368322712144020405, 7511427312857841, -6395442121119305], [2808625396197316296, -19949177114639964, -20181374254301412], [-7162688951634654415, -36657402703962969, -11718551543970383], [-2969660283965147896, -101960609726077302, 8942390622765286], [2230659576262358324, 32753074702009860, -16560210931140036], [-4704133325351685892, 35052527233859706, -1960648952736586], [-217565433681456712, 10763799984217748, -13170313436021236], [-3009149416047258425, 75392145473624225, 17192129349407559], [-7026157317668109706, -11961033228998388, 5901985299726804], [-2059535453922904337, -75702573952787337, -13793878183842271], [-8096240882414093056, -47016253520150454, -11441579432572154], [4104990299216843419, -48542901486769553, -8129813736099191], [2924224209166705438, 84015520468884264, 2929242515924696], [-708320364134712284, 204245056038932820, 9268552524539724], [-2003821525972973478, -103082301801033884, -11970843420704452], [3135043989588392884, 2648497066717536, 13352225501864864], [-2440519332649950724, 14451861087973132, 20043559600280340], [4891139510670967912, -138452876835378408, -4555942456961048], [-3721978688521158780, -53882430049738638, -10972590117140546], [-7611755249856005338, 47534607156156174, -10156684651672158], [-2008435663081075538, -46813886428141614, 9798045621880958], [-1620199466328681356, -90599225748508962, -8470092159977934], [-1859710028287455755, -100123660224556707, -1501063468726261], [4457814648260622017, 130489178951170131, -32488370686010075], [4404896103939905432, -15406285006106964, 8645027565950292], [888557600518081249, 5041167774502831, 20756897136623593], [-5162790351292039882, 12713566029455124, -3611253298809076], [9579605402186455900, -94624951159317852, 2925865415790588], [-3948319234631312697, 106798992418234071, 13687756026303297], [-2267003515775455882, -122454619000668306, 34295082373676866], [-4871495207422125330, 157385289125343300, 17521345715081724], [-9131485757925269402, -76786439227350696, 5604094933509640], [-4417131569599273030, 51348671892863236, -30465198470677668], [-606284128996537786, -220171906368816534, -83539631547994], [2866606275721004661, -110642706472712151, -13704817119824961], [6736908547763457957, 35335116062471517, 21242627944048011], [1898712663683045160, 172306239001124688, 31827761018127664], [-2234600147944389044, 1228729322480922, 20787101149698326], [-7133770878224399090, 165966989000300992, 863674438260736], [3590395936722149924, 23393658739421088, 35664842713155360], [1424659054000727282, -86038307866882230, -26380922921029946], [3053157900119647498, 112120410327422760, 42119953535056600], [-1575647012940529614, -185679690488196320, 31859642951008640], [2501838471667989067, -80979570338161991, -19941987423299921], [-5026921181989049724, -191284982233957224, 6715010543821864], [6436259401205010284, -26960044368094434, 6325907849387506], [771623149715022161, -62985077907056487, -19363141439421521], [5955901837213950091, -273188859269403699, -6277995637311877], [8605196616097593976, 123115173785544384, 33782483605066528], [-8383573538980763781, -35569885250807253, 18410522439633933], [-1000140037802802982, 101173680691294542, -4133755198386206], [-61833740260312798, 253445077060137720, 27657050011882024], [-5871391323167074534, 33167104407899100, 11719118344561124], [8602021710928266741, 120930639306111427, -41579308156956043], [-696076083546319736, 190988723067739804, 52792704413913412], [-7071147459394460102, -36098211222315504, -33550010864859344], [-525764462633281801, -190578962229812781, -5616772219843835], [495144731058972947, 165564052589637641, 40326376666335071], [-12563702512386124532, -6839482438721382, -36927250684000906], [4462072505167266156, 17407324459182960, -41963308579975152], [-1981428831815406630, -228783830169651042, -2464842783625902]]
